@@ -3,10 +3,11 @@ from __future__ import annotations
 import ast
 import asyncio
 import itertools
+import os
 import re
 from collections import defaultdict
 from dataclasses import dataclass
-from typing import Any, AsyncGenerator, Dict, List, Optional, Set, Tuple, Union, cast
+from typing import Any, Dict, Generator, List, Optional, Set, Tuple, Union, cast
 
 from ....utils.uri import Uri
 from ...common.lsp_types import (
@@ -35,7 +36,11 @@ from ..utils.ast_utils import (
 )
 from ..utils.async_ast import AsyncVisitor
 from ..utils.version import get_robot_version
-from .entities import VariableDefinition, VariableNotFoundDefinition
+from .entities import (
+    EnvironmentVariableDefinition,
+    VariableDefinition,
+    VariableNotFoundDefinition,
+)
 from .library_doc import KeywordDoc, is_embedded_keyword
 from .namespace import DIAGNOSTICS_SOURCE_NAME, KeywordFinder, Namespace
 
@@ -73,7 +78,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
 
         return AnalyzerResult(self._diagnostics, self._keyword_references, self._variable_references)
 
-    async def yield_argument_name_and_rest(self, node: ast.AST, token: Token) -> AsyncGenerator[Token, None]:
+    def yield_argument_name_and_rest(self, node: ast.AST, token: Token) -> Generator[Token, None, None]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import Arguments
 
@@ -95,7 +100,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 yield argument
                 i = len(argument.value)
 
-                async for t in self.yield_argument_name_and_rest(
+                for t in self.yield_argument_name_and_rest(
                     node, RobotToken(token.type, token.value[i:], token.lineno, token.col_offset + i, token.error)
                 ):
                     yield t
@@ -173,7 +178,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                     and t.error is None
                     and contains_variable(t.value, "$@&%")
                 ):
-                    async for token in self.yield_argument_name_and_rest(node, token1):
+                    for token in self.yield_argument_name_and_rest(node, token1):
                         if isinstance(node, Arguments) and token.value == "@{}":
                             continue
 
@@ -194,8 +199,24 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                                     code="VariableNotFound",
                                 )
                             else:
+                                if isinstance(var, EnvironmentVariableDefinition) and var.default_value is None:
+                                    env_name = var.name[2:-1]
+                                    if os.environ.get(env_name, None) is None:
+                                        await self.append_diagnostics(
+                                            range=range_from_token(var_token),
+                                            message=f"Environment variable '{var.name}' not found.",
+                                            severity=severity,
+                                            source=DIAGNOSTICS_SOURCE_NAME,
+                                            code="EnvirommentVariableNotFound",
+                                        )
+
                                 if self.namespace.document is not None:
-                                    var_range = range_from_token(var_token)
+                                    if isinstance(var, EnvironmentVariableDefinition):
+                                        var_token.value, _, _ = var_token.value.partition("=")
+
+                                        var_range = range_from_token(var_token)
+                                    else:
+                                        var_range = range_from_token(var_token)
                                     if var.name_range != var_range:
                                         self._variable_references[var].add(
                                             Location(self.namespace.document.document_uri, var_range)
@@ -309,6 +330,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
         argument_tokens: List[Token],
         analyse_run_keywords: bool = True,
         allow_variables: bool = False,
+        ignore_errors_if_contains_variables: bool = False,
     ) -> Optional[KeywordDoc]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import Template, TestTemplate
@@ -350,13 +372,14 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
 
             result = await self.finder.find_keyword(keyword)
 
-            for e in self.finder.diagnostics:
-                await self.append_diagnostics(
-                    range=kw_range,
-                    message=e.message,
-                    severity=e.severity,
-                    code=e.code,
-                )
+            if not ignore_errors_if_contains_variables or is_not_variable_token(keyword_token):
+                for e in self.finder.diagnostics:
+                    await self.append_diagnostics(
+                        range=kw_range,
+                        message=e.message,
+                        severity=e.severity,
+                        code=e.code,
+                    )
 
             if result is not None:
                 if self.namespace.document is not None:
@@ -523,22 +546,27 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
         if keyword_doc is None or not keyword_doc.is_any_run_keyword():
             return argument_tokens
 
-        if keyword_doc.is_run_keyword() and len(argument_tokens) > 0 and is_not_variable_token(argument_tokens[0]):
+        if keyword_doc.is_run_keyword() and len(argument_tokens) > 0:
             await self._analyze_keyword_call(
-                unescape(argument_tokens[0].value), node, argument_tokens[0], argument_tokens[1:]
+                unescape(argument_tokens[0].value),
+                node,
+                argument_tokens[0],
+                argument_tokens[1:],
+                allow_variables=True,
+                ignore_errors_if_contains_variables=True,
             )
 
             return argument_tokens[1:]
-        elif (
-            keyword_doc.is_run_keyword_with_condition()
-            and len(argument_tokens) > (cond_count := keyword_doc.run_keyword_condition_count())
-            and is_not_variable_token(argument_tokens[cond_count])
+        elif keyword_doc.is_run_keyword_with_condition() and len(argument_tokens) > (
+            cond_count := keyword_doc.run_keyword_condition_count()
         ):
             await self._analyze_keyword_call(
                 unescape(argument_tokens[cond_count].value),
                 node,
                 argument_tokens[cond_count],
                 argument_tokens[cond_count + 1 :],
+                allow_variables=True,
+                ignore_errors_if_contains_variables=True,
             )
             return argument_tokens[cond_count + 1 :]
         elif keyword_doc.is_run_keywords():
@@ -556,9 +584,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                     )
                     continue
 
-                if not is_not_variable_token(t):
-                    continue
-
                 and_token = next((e for e in argument_tokens if e.value == "AND"), None)
                 args = []
                 if and_token is not None:
@@ -569,7 +594,14 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                     args = argument_tokens
                     argument_tokens = []
 
-                await self._analyze_keyword_call(unescape(t.value), node, t, args)
+                await self._analyze_keyword_call(
+                    unescape(t.value),
+                    node,
+                    t,
+                    args,
+                    allow_variables=True,
+                    ignore_errors_if_contains_variables=True,
+                )
 
             return []
 
@@ -599,14 +631,15 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
 
                 args = skip_args()
 
-                if is_not_variable_token(kwt):
-                    await self._analyze_keyword_call(
-                        unescape(kwt.value),
-                        node,
-                        kwt,
-                        args,
-                        analyse_run_keywords=False,
-                    )
+                await self._analyze_keyword_call(
+                    unescape(kwt.value),
+                    node,
+                    kwt,
+                    args,
+                    analyse_run_keywords=False,
+                    allow_variables=True,
+                    ignore_errors_if_contains_variables=True,
+                )
 
             while argument_tokens:
                 if argument_tokens[0].value == "ELSE" and len(argument_tokens) > 1:
@@ -661,12 +694,16 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
 
         if (
             keyword_token is not None
-            and is_not_variable_token(keyword_token)
             and keyword_token.value is not None
             and keyword_token.value.upper() not in ("", "NONE")
         ):
             await self._analyze_keyword_call(
-                value.name, value, keyword_token, [cast(Token, e) for e in value.get_tokens(RobotToken.ARGUMENT)]
+                value.name,
+                value,
+                keyword_token,
+                [cast(Token, e) for e in value.get_tokens(RobotToken.ARGUMENT)],
+                allow_variables=True,
+                ignore_errors_if_contains_variables=True,
             )
 
         await self.generic_visit(node)
